"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.listAppPlansByAppId = exports.TaxType = exports.BillingSource = exports.CycleType = exports.DurationUnit = exports.SourceType = exports.DiscountType = exports.SaleType = void 0;
const transform_error_1 = require("@wix/sdk-runtime/transform-error");
const rename_all_nested_keys_1 = require("@wix/sdk-runtime/rename-all-nested-keys");
const ambassadorWixAppmarketV1AppPlans = __importStar(require("./appmarket-v1-app-plans-app-plans.http.js"));
var SaleType;
(function (SaleType) {
    /** Default value, can be used when no specific sale is associated. */
    SaleType["SALE_TYPE_UNSPECIFIED"] = "SALE_TYPE_UNSPECIFIED";
    SaleType["CYBER_MONDAY"] = "CYBER_MONDAY";
    SaleType["NOVEMBER_SALE"] = "NOVEMBER_SALE";
    SaleType["BLACK_FRIDAY"] = "BLACK_FRIDAY";
    SaleType["DEVELOPER_SALE"] = "DEVELOPER_SALE";
})(SaleType || (exports.SaleType = SaleType = {}));
var DiscountType;
(function (DiscountType) {
    DiscountType["DISCOUNT_TYPE_UNSPECIFIED"] = "DISCOUNT_TYPE_UNSPECIFIED";
    /** Discount is a fixed amount in USD. */
    DiscountType["FIXED_AMOUNT"] = "FIXED_AMOUNT";
    /** Discount is a percentage of the total price. */
    DiscountType["PERCENTAGE"] = "PERCENTAGE";
})(DiscountType || (exports.DiscountType = DiscountType = {}));
var SourceType;
(function (SourceType) {
    /** Default value, can be used when no specific source is associated. */
    SourceType["SOURCE_TYPE_UNSPECIFIED"] = "SOURCE_TYPE_UNSPECIFIED";
    /** Discount is due to Wix/Developer Sale */
    SourceType["SALE"] = "SALE";
    /** Discount is due to App Benefit */
    SourceType["APP_BENEFIT"] = "APP_BENEFIT";
})(SourceType || (exports.SourceType = SourceType = {}));
var DurationUnit;
(function (DurationUnit) {
    /** unknown interval unit */
    DurationUnit["UNKNOWN_UNIT"] = "UNKNOWN_UNIT";
    /** month */
    DurationUnit["MONTH"] = "MONTH";
    /** year */
    DurationUnit["YEAR"] = "YEAR";
})(DurationUnit || (exports.DurationUnit = DurationUnit = {}));
var CycleType;
(function (CycleType) {
    CycleType["UNKNOWN_TYPE"] = "UNKNOWN_TYPE";
    CycleType["ONE_TIME"] = "ONE_TIME";
    CycleType["RECURRING"] = "RECURRING";
})(CycleType || (exports.CycleType = CycleType = {}));
var BillingSource;
(function (BillingSource) {
    BillingSource["UNKNOWN"] = "UNKNOWN";
    /** plan billing and charges is managed by Wix */
    BillingSource["WIX"] = "WIX";
    /** plan billing and charges is managed by the app */
    BillingSource["EXTERNAL"] = "EXTERNAL";
})(BillingSource || (exports.BillingSource = BillingSource = {}));
var TaxType;
(function (TaxType) {
    TaxType["NOT_APPLICABLE"] = "NOT_APPLICABLE";
    TaxType["VAT"] = "VAT";
    TaxType["GST"] = "GST";
})(TaxType || (exports.TaxType = TaxType = {}));
/**
 * Retrieves plans for the given apps.
 *
 *
 * Also returns tax settings and currency details. Wix calculates this information
 * based on the 2-letter country code in [ISO-3166 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2#Officially_assigned_code_elements)
 * format that you pass in the call's header. If you don't pass a country code in
 * the header, Wix calculates the tax settings and currency details based on the
 * call's IP address. Note that the tax settings and currency details may not resolve
 * properly if you call through a VPN.
 *
 * Prices for plans that are managed outside of Wix aren't returned.
 *
 * Consumers must pay for yearly and multi-yearly plans of your app every month.
 * For these plans this method returns the price that the consumer must pay every
 * month and not the total price for the entire year.
 *
 * > **Notes:**
 * > - The App Plans API doesn't follow any tenancy model. You don't need any permissions to call `List App Plans by App ID`.
 * > - This method only returns app plans that have been activated.
 * @param appIds - List of app IDs to retrieve plans for.
 *
 * Min: 1 app ID
 * Max: 100 app IDs
 * @public
 * @documentationMaturity preview
 * @requiredField appIds
 * @fqn wix.appmarket.app_plans.v1.AppsPlans.ListAppPlansByAppId
 */
async function listAppPlansByAppId(appIds) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({ appIds: appIds });
    const reqOpts = ambassadorWixAppmarketV1AppPlans.listAppPlansByAppId(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { appIds: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['appIds']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.listAppPlansByAppId = listAppPlansByAppId;
//# sourceMappingURL=appmarket-v1-app-plans-app-plans.universal.js.map