import { HttpClient } from '@wix/sdk-types';
import { ListAppPlansByAppIdResponse } from './appmarket-v1-app-plans-app-plans.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function listAppPlansByAppId(httpClient: HttpClient): ListAppPlansByAppIdSignature;
interface ListAppPlansByAppIdSignature {
    /**
     * Retrieves plans for the given apps.
     *
     *
     * Also returns tax settings and currency details. Wix calculates this information
     * based on the 2-letter country code in [ISO-3166 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2#Officially_assigned_code_elements)
     * format that you pass in the call's header. If you don't pass a country code in
     * the header, Wix calculates the tax settings and currency details based on the
     * call's IP address. Note that the tax settings and currency details may not resolve
     * properly if you call through a VPN.
     *
     * Prices for plans that are managed outside of Wix aren't returned.
     *
     * Consumers must pay for yearly and multi-yearly plans of your app every month.
     * For these plans this method returns the price that the consumer must pay every
     * month and not the total price for the entire year.
     *
     * > **Notes:**
     * > - The App Plans API doesn't follow any tenancy model. You don't need any permissions to call `List App Plans by App ID`.
     * > - This method only returns app plans that have been activated.
     * @param - List of app IDs to retrieve plans for.
     *
     * Min: 1 app ID
     * Max: 100 app IDs
     */
    (appIds: string[]): Promise<ListAppPlansByAppIdResponse>;
}
export { AppPlanInfo, AppPlans, BillingSource, Cycle, CycleType, Discount, DiscountSourceDataOneOf, DiscountType, Duration, DurationUnit, GetAvailableAppPlansRequest, GetAvailableAppPlansResponse, GetPricingPageUrlRequest, GetPricingPageUrlResponse, ListAppPlansByAppIdRequest, ListAppPlansByAppIdResponse, Plan, Price, SaleSource, SaleType, SourceType, TaxSettings, TaxType, UsageBasedDetails, } from './appmarket-v1-app-plans-app-plans.universal.js';
