import { toURLSearchParams } from '@wix/sdk-runtime/rest-modules';
import { transformRESTTimestampToSDKTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
import { resolveUrl } from '@wix/sdk-runtime/rest-modules';
function resolveWixAppmarketAppPlansV1AppsPlansUrl(opts) {
    const domainToMappings = {
        'api._api_base_domain_': [
            {
                srcPath: '/apps-plans',
                destPath: '',
            },
        ],
        'manage._base_domain_': [
            {
                srcPath: '/_api/app-market/apps-plans',
                destPath: '/api',
            },
            {
                srcPath: '/api/apps-plans',
                destPath: '',
            },
            {
                srcPath: '/apps-plans',
                destPath: '',
            },
        ],
        'bo._base_domain_': [
            {
                srcPath: '/_api/apps-plans',
                destPath: '',
            },
            {
                srcPath: '/apps-plans',
                destPath: '',
            },
        ],
        'wixbo.ai': [
            {
                srcPath: '/_api/apps-plans',
                destPath: '',
            },
            {
                srcPath: '/apps-plans',
                destPath: '',
            },
        ],
        'wix-bo.com': [
            {
                srcPath: '/_api/apps-plans',
                destPath: '',
            },
            {
                srcPath: '/apps-plans',
                destPath: '',
            },
        ],
        'editor._base_domain_': [
            {
                srcPath: '/_api/apps-plans',
                destPath: '',
            },
        ],
        'blocks._base_domain_': [
            {
                srcPath: '/_api/apps-plans',
                destPath: '',
            },
        ],
        'create.editorx': [
            {
                srcPath: '/_api/apps-plans',
                destPath: '',
            },
        ],
        'www._base_domain_': [
            {
                srcPath: '/apps-plans',
                destPath: '',
            },
            {
                srcPath: '/_api/apps-plans',
                destPath: '',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/apps-plans',
                destPath: '',
            },
        ],
    };
    return resolveUrl(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_app-management_app-plans';
/**
 * Retrieves plans for the given apps.
 *
 *
 * Also returns tax settings and currency details. Wix calculates this information
 * based on the 2-letter country code in [ISO-3166 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2#Officially_assigned_code_elements)
 * format that you pass in the call's header. If you don't pass a country code in
 * the header, Wix calculates the tax settings and currency details based on the
 * call's IP address. Note that the tax settings and currency details may not resolve
 * properly if you call through a VPN.
 *
 * Prices for plans that are managed outside of Wix aren't returned.
 *
 * Consumers must pay for yearly and multi-yearly plans of your app every month.
 * For these plans this method returns the price that the consumer must pay every
 * month and not the total price for the entire year.
 *
 * > **Notes:**
 * > - The App Plans API doesn't follow any tenancy model. You don't need any permissions to call `List App Plans by App ID`.
 * > - This method only returns app plans that have been activated.
 */
export function listAppPlansByAppId(payload) {
    function __listAppPlansByAppId({ host }) {
        const metadata = {
            entityFqdn: 'wix.appmarket.v1.app_plans',
            method: 'GET',
            methodFqn: 'wix.appmarket.app_plans.v1.AppsPlans.ListAppPlansByAppId',
            packageName: PACKAGE_NAME,
            url: resolveWixAppmarketAppPlansV1AppsPlansUrl({
                protoPath: '/v1/apps-plans/{appIds}',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'appPlans.plans.prices.discount.saleOptions.startDate' },
                        { path: 'appPlans.plans.prices.discount.saleOptions.endDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __listAppPlansByAppId;
}
//# sourceMappingURL=appmarket-v1-app-plans-app-plans.http.js.map